History
=======

0.1.1 (July 25th, 2022)
-----------------------

* Fix scrubber where paths that were valid, but didn't point to something in an
  event erroneously kicked up a RulePathError. (#12)

* Fix test examples in docs.

* Fix examples in README. Thanks @stevejalim!


0.1.0 (June 23rd, 2022)
-----------------------

* Inital extraction and writing.
